News and Changelog
==============================

* 0.6.0 (26/05/22)

  - Fixed bug where the prediction visualizer repeats text when there is overlapping span. and intensifiers were considered outside of the sentences boundaries. Adressing `#57 <https://github.com/KennethEnevoldsen/asent/issues/57>`__
  - To use the new visualizers asent now required spacy version >= 3.3.0. However, can be run with spacy>=3.0.0.
  - Updates to documentation

* 0.5.3 (26/05/22)

  - Fixed bug where negation and intensifiers were considered outside of the sentences boundaries. Adressing `58 <https://github.com/KennethEnevoldsen/asent/issues/58>`__.
  - Improvements to the documentation. Thanks to @tomaarsen for the pull request.

* 0.4.2 (28/05/22)

  - Added new Danish Dictionary from `AFINN <https://github.com/fnielsen/afinn>`__
  - Asent now support 81 languages using the autogenerated lexicons from `Chen, Y., & Skiena, S. (2014) <https://aclanthology.org/P14-2063.pdf>`__.
  - Fixed minor bugs related to the Visualizer
  - Fixed spaCy pipelines used in text to allow for more consistent tests going forward.
  - Added pre-commit hooks to ensure future code quality.


* 0.1.3 (02/01/22)

  - 96% Coverage on pytest 🎉
  - New Visualizer for visualizing the "analysis" of the model, using spaCy dependency Visualizer
  - New CI for Tutorials to ensure that they always run

* 0.1.0 (26/12/21)

  - Major updates to the documentation along with two new tutorials 📖
  - Cool new infographics 😎
  - Changes:

    * ``make_token_polarity_getter`` no longer takes the ``is_negation_getter``, but the ``is_negated_getter`` to avoid it setting the ``is_negated`` setting itself, potentially overwriting custom changes.

  - bug-fixes 🪲:

    * Lexicons is now properly installed with the package
    * Empty string no longer causes a bug
    * All extentions are now overwritten when ``force=True``
    * And many more


* 0.0.3 (05/12/21)

  - First version of asent launches
  
    * with four different languages supported, some of which have never had rule-based sentiment models 🎉
    * Tutorials allowing you to get started using and customizing your sentiment pipeline 🔧
    * Visualizers for examining the predictions of the model 🌟 
    * An extensive docuementation 📖

